.. lineage documentation master file, created by
   sphinx-quickstart on Wed Jul 19 23:32:11 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. image:: https://raw.githubusercontent.com/apriha/lineage/master/docs/images/lineage_banner.png

`lineage`
=========

*tools for genetic genealogy and the analysis of consumer DNA test results*

.. toctree::
   :maxdepth: 2
   :caption: Contents

   README <readme>
   output_files
   changelog
   contributing
   contributors
   lineage

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
